@@ -541,17 +541,33 @@ class ThothPgManager(ThothDbManager):
                 column_name = col_info['name']
                 column_type = str(col_info['type']).lower()
                 
-                # Skip text type columns
-                if 'text' in column_type:
-                    logging.info(f"Skipping text column: {column_name}")
-                    continue
-                
                 # Ensure column name is properly quoted for the SQL query
                 # The specific quoting character might depend on the SQL dialect,
                 # but PostgreSQL uses double quotes.
                 quoted_column_name = f'"{column_name}"'
                 quoted_schema_name = f'"{self.schema}"'
                 quoted_table_name = f'"{table_name}"'
+                
+                # Handle text type columns differently - extract 30 non-null, non-blank values
+                if 'text' in column_type:
+                    logging.info(f"Processing text column: {column_name}")
+                    
+                    # Query to get 30 non-null, non-blank text values without sorting
+                    text_query_str = f"""
+                        SELECT {quoted_column_name}
+                        FROM {quoted_schema_name}.{quoted_table_name}
+                        WHERE {quoted_column_name} IS NOT NULL 
+                          AND TRIM({quoted_column_name}) != ''
+                        LIMIT 30;
+                    """
+                    try:
+                        result = connection.execute(text(text_query_str))
+                        values = [row[0] for row in result]
+                        most_frequent_values[column_name] = values
+                    except SQLAlchemyError as e:
+                        logging.error(f"Error fetching text values for {column_name} in {table_name}: {e}")
+                        most_frequent_values[column_name] = []
+                    continue
 
                 # Query to get most frequent values from a limited dataset of 1000 records
                 query_str = f"""
@@ -562,7 +578,7 @@ class ThothPgManager(ThothDbManager):
                             SELECT {quoted_column_name}
                             FROM {quoted_schema_name}.{quoted_table_name}
                             WHERE {quoted_column_name} IS NOT NULL
-                            LIMIT 1000
+                            LIMIT 10000
                         ) as limited_data
                         GROUP BY {quoted_column_name}
                         ORDER BY _freq DESC
