@@ -343,7 +343,7 @@ class ThothSqliteManager(ThothDbManager):
         Uses SQLAlchemy for database interaction.
         
         Modifications:
-        1. Limits to 1000 records for frequency calculation
+        1. Limits to 10000 records for frequency calculation
         2. Skips text type columns
         """
         inspector = inspect(self.engine)
@@ -364,15 +364,31 @@ class ThothSqliteManager(ThothDbManager):
                 column_name = col_info['name']
                 column_type = str(col_info['type']).lower()
                 
-                # Skip text type columns
-                if 'text' in column_type:
-                    logging.info(f"Skipping text column: {column_name}")
-                    continue
-                
                 quoted_column_name = f'"{column_name}"'
                 quoted_table_name = f'"{table_name}"'
+                
+                # Handle text type columns differently - extract 30 non-null, non-blank values
+                if 'text' in column_type:
+                    logging.info(f"Processing text column: {column_name}")
+                    
+                    # Query to get 30 non-null, non-blank text values without sorting
+                    text_query_str = f"""
+                        SELECT {quoted_column_name}
+                        FROM {quoted_table_name}
+                        WHERE {quoted_column_name} IS NOT NULL 
+                          AND TRIM({quoted_column_name}) != ''
+                        LIMIT 30;
+                    """
+                    try:
+                        result = connection.execute(text(text_query_str))
+                        values = [row[0] for row in result]
+                        most_frequent_values[column_name] = values
+                    except SQLAlchemyError as e:
+                        logging.error(f"Error fetching text values for {column_name} in {table_name} ({self.db_id}.sqlite): {e}")
+                        most_frequent_values[column_name] = []
+                    continue
 
-                # Query to get most frequent values from a limited dataset of 1000 records
+                # Query to get most frequent values from a limited dataset of 10000 records
                 query_str = f"""
                     SELECT {quoted_column_name}
                     FROM (
@@ -381,7 +397,7 @@ class ThothSqliteManager(ThothDbManager):
                             SELECT {quoted_column_name}
                             FROM {quoted_table_name}
                             WHERE {quoted_column_name} IS NOT NULL
-                            LIMIT 1000
+                            LIMIT 10000
                         ) as limited_data
                         GROUP BY {quoted_column_name}
                         ORDER BY _freq DESC
